@@ -24,7 +24,6 @@
 #' @examples
 #' interpret_rope(0, ci = 0.9)
 #' interpret_rope(c(0.005, 0.99), ci = 1)
-#'
 #' @references
 #' [BayestestR's reporting guidelines](https://easystats.github.io/bayestestR/articles/guidelines.html)
 #'
@@ -34,14 +33,18 @@ interpret_rope <- function(rope, ci = 0.9, rules = "default") {
     e <- .Machine$double.eps
 
     default_rule <- rules(c(0, 0 + e, 1 - e, 1),
-                          c("significant", "undecided", "undecided", "negligible"),
-                          name = "default")
+      c("significant", "undecided", "undecided", "negligible"),
+      name = "default"
+    )
   } else {
     default_rule <- rules(c(0.01, 0.025, 0.975, 0.99),
-                          c("significant", "probably significant",
-                            "undecided",
-                            "probably negligible", "negligible"),
-                          name = "default")
+      c(
+        "significant", "probably significant",
+        "undecided",
+        "probably negligible", "negligible"
+      ),
+      name = "default"
+    )
   }
 
   rules <- .match.rules(
