@@ -16,11 +16,7 @@ NULL
 #' @rdname effectsize_deprecated
 #' @export
 interpret_d <- function(...) {
-
-  ## TODO deprecate later
-  # .Deprecated("interpret_cohens_d")
-
-  message("'interpret_d()' is now deprecated. Please use 'interpret_cohens_d()'.")
+  .Deprecated("interpret_cohens_d")
   interpret_cohens_d(...)
 }
 
@@ -43,4 +39,4 @@ interpret_delta <- function(...) {
 interpret_parameters <- function(...) {
   .Deprecated("interpret_r")
   interpret_r(...)
-}
\ No newline at end of file
+}
