@@ -1,11 +1,11 @@
 ## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
 library(knitr)
-options(knitr.kable.NA = '')
-knitr::opts_chunk$set(comment=">")
-options(digits=2)
+options(knitr.kable.NA = "")
+knitr::opts_chunk$set(comment = ">")
+options(digits = 2)
 
 pkgs <- c("effectsize")
-if (!all(sapply(pkgs, requireNamespace))) {
+if (!all(sapply(pkgs, requireNamespace, quietly = TRUE))) {
   knitr::opts_chunk$set(eval = FALSE)
 }
 
